@@ -10,8 +10,10 @@
 #' `format_power()` converts the numbers to character strings of the form, `"$a
 #' \\times 10^{n}$"`, where `a` is the coefficient and `n` is the exponent. The
 #' string includes markup delimiters `$...$` for rendering as an inline equation
-#' in R Markdown or Quarto Markdown document. The user can specify the number of
-#' significant digits and scientific or engineering format.
+#' in R Markdown or Quarto Markdown document.
+#'
+#' The user can specify either scientific or engineering format and
+#' the number of significant digits.
 #'
 #' Powers-of-ten notation is omitted over a range of exponents via `omit_power`
 #' such that numbers are converted to character strings of the form, `"$a$"`,
@@ -21,21 +23,29 @@
 #' set the `omit_power` argument to NULL.
 #'
 #' Delimiters for inline math markup can be edited if necessary. If the default
-#' argument fails, the `"\\("` alternative is available. If using a custom
+#' argument fails, try using `"\\("` as an alternative. If using a custom
 #' delimiter to suit the markup environment, be sure to escape all special
 #' symbols.
 #'
 #' @param x Numeric vector to be formatted.
-#' @param digits Numeric scalar, significant digits in coefficient, integer
-#'   between 1 and 20.
+#' @param digits Numeric scalar between 1 and 20 (inclusive) defining the
+#'   number of significant digits in result.
 #' @param ... Not used, force later arguments to be used by name.
-#' @param format Character. Possible values are "engr" (engineering notation)
-#'   and "sci" (scientific notation). Use argument  by name.
+#' @param format Character. Possible values are "engr" (default) for engineering
+#'   notation and and "sci" for scientific notation. Use argument  by name. Can
+#'   also be set as a global option, for example,
+#'   `options(formatdown.power.format = "sci")` that can be overwritten
+#'   in an individual function call.
+#' @param size Font size. Possible values are "scriptsize", "small" (default),
+#'   "normalsize", "large", and "huge". which correspond to selected
+#'   LaTeX font size values. Can also be set as a global option, for example,
+#'   `options(formatdown.font.size = "normalsize")` that can be overwritten
+#'   in an individual function call.
 #' @param omit_power Numeric vector `c(p, q)` specifying the range of exponents
-#'   over which power of ten notation is omitted, where `p <= q`. If NULL all
+#'   between which power of ten notation is omitted, where `p <= q`. If NULL all
 #'   numbers are formatted in powers of ten notation. Use argument by name.
 #' @param set_power Numeric scalar integer. Assigned exponent that overrides
-#'   `format`. Default NULL makes no notation changes.
+#'   `format`. Default NULL makes no notation changes. Use argument by name.
 #' @param delim Character vector (length 1 or 2) defining the delimiters for
 #'   marking up inline math. Possible values include `"$"` or `"\\("`, both of
 #'   which create appropriate left and right delimiters. Alternatively, left and
@@ -54,7 +64,8 @@
 format_power <- function(x,
                          digits = 4,
                          ...,
-                         format = "engr",
+                         format = NULL,
+                         size = NULL,
                          omit_power = c(-1, 2),
                          set_power = NULL,
                          delim = "$") {
@@ -72,6 +83,26 @@ format_power <- function(x,
   )
   wrapr::stop_if_dot_args(substitute(list(...)), stop_if_dots_text)
 
+
+
+  # Determine the value assigned to format
+  if (isTRUE(!is.null(format))) {
+    # Use the value from the argument list
+    format <- format
+  } else {
+    # Use the value assigned as an option, otherwise use default
+    format <- getOption("formatdown.power.format", default = "engr")
+  }
+
+  # Determine the value assigned to size
+  if (isTRUE(!is.null(size))) {
+    # Use the value from the argument list
+    size <- size
+  } else {
+    # Use the value assigned as an option, otherwise use default
+    size <- getOption("formatdown.font.size", default = "small")
+  }
+
   # More informative error for digits/format specifically
   if (!isTRUE(class(digits) == "numeric")) {stop(stop_if_dots_text)}
 
@@ -90,6 +121,8 @@ format_power <- function(x,
   exponent <- NULL
   coeff <- NULL
   value <- NULL
+  omit_check <- NULL
+  size_markup <- NULL
 
   # Argument checks ---------------------------------------------------------
 
@@ -101,11 +134,17 @@ format_power <- function(x,
   checkmate::qassert(digits, "N1")
   checkmate::assert_choice(digits, choices = c(1:20))
 
-
   # format: character, not missing, length 1, element of set
   checkmate::qassert(format, "S1")
   checkmate::assert_choice(format, choices = c("engr", "sci"))
 
+  # size: character, not missing, length 1, element of set
+  checkmate::qassert(size, "S1")
+  checkmate::assert_choice(
+    size,
+    choices = c("scriptsize", "small", "normalsize", "large", "huge")
+  )
+
   # set_power: numeric, length 1 (can be NA)
   checkmate::qassert(set_power, "n1")
 
@@ -122,20 +161,31 @@ format_power <- function(x,
 
   # Initial processing ------------------------------------------------------
 
+  # Size format for math markup ----------------------------------------------
+  if(size == "huge")       size_markup  <- "\\huge"
+  if(size == "large")      size_markup  <- "\\large"
+  if(size == "normalsize") size_markup  <- "\\normalsize"
+  if(size == "small")      size_markup  <- "\\small"
+  if(size == "scriptsize") size_markup  <- "\\scriptsize"
+
   # Convert vector to data.table for processing
   DT <- data.table::copy(data.frame(x))
   setDT(DT)
 
-  # Set exponent to 0 if x close to zero
-  DT[, exponent := data.table::fifelse(
-    abs(x) > .Machine$double.eps,
-    log10(abs(x)),
-    0)]
+  # Set significant digits before processing
+  DT[, x := signif(x, digits = digits)]
+
+  # Obtain exponent as a decimal value
+  DT[, exponent := log10(abs(x))]
 
   # Obtain row indices to separate powers-of-ten from non-powers-of-ten
-  non_pow <- DT$exponent %between% omit_power
+  DT[, omit_check := floor(exponent)]
+  non_pow <- DT$omit_check %between% omit_power
   pow_10  <- !non_pow
 
+  # clean up
+  DT[, omit_check := NULL]
+
   # Exponent multiple for scientific or engineering notation
   exp_multiple <- data.table::fcase(
     format == "engr", 3,
@@ -154,6 +204,9 @@ format_power <- function(x,
   # (see utils.R)
   DT[non_pow] <- omit_formatC_extras(DT[non_pow], col_name = "value")
 
+  # Add font size
+  DT[non_pow, value := paste0(size_markup, " ", value)]
+
   # Power rows ------------------------------------------------------
 
   # Determine exponent
@@ -165,11 +218,7 @@ format_power <- function(x,
   } else {
 
     # Round to multiple of 1 (scientific) or 3 (engineering)
-    # Set exponent to 0 if x close to zero
-    DT[pow_10, exponent := data.table::fifelse(
-      abs(x) > .Machine$double.eps,
-      exp_multiple * floor(log10(abs(x)) / exp_multiple),
-      0)]
+    DT[pow_10, exponent := exp_multiple * floor(log10(abs(x)) / exp_multiple)]
 
   }
 
@@ -182,12 +231,12 @@ format_power <- function(x,
                                    digits = digits,
                                    flag = "#")]
 
-  # Remove trailing decimal point and spaces created by formatC() if any
+  # Remove trailing decimal point and spaces if any created by formatC()
   # (see utils.R)
   DT[pow_10] <- omit_formatC_extras(DT[pow_10], col_name = "char_coeff")
 
   # Construct powers-of-ten character string
-  DT[pow_10, value := paste0(char_coeff, " \\times ", "10^{", exponent, "}")]
+  DT[pow_10, value := paste0(size_markup, " ", char_coeff, " \\times ", "10^{", exponent, "}")]
 
   # Output ------------------------------------------------------
 
